@@ -25,6 +25,16 @@ class PinCreator(ABC):
         pass
 
 
+class FA2DPinsCreator(ABC):
+    def __init__(self):
+        self.pins = []
+        pass
+
+    @abstractmethod
+    def create_pins(self, cells_numbers, cells_types, pins_materials, pins_radiuses):
+        pass
+
+
 class NumberedPinsCreator(ABC):
     @abstractmethod
     def __init__(self, number, materials, radiuses):
